source: [PersianJS](https://github.com/usablica/persian.js)

## Persian.js
A simple JavaScript library for Persian language localization.

-----

### How to use
Simply include persian.js in your HTML page and use the functions.
If your in production environment, use persian.min.js instead.

### In Node.js
`npm install persianjs`

### Functions
1. Convert to Persian characters
Used for converting Arabic characters to Persian

Example:

`persianJs("علي").toPersianChar(); // returns: علی`

2. Convert to English numbers from Persian Number
Used for converting Persian numbers to English.

Example:

`persianJs("۳۴۵").persianNumber(); // returns: 345`

3. Convert to Persian numbers from Arabic Number
Used for converting Arabic numbers to Persian.

Example:

`persianJs("٣٤٥").arabicNumber(); // returns: ۳۴۵`

4. Convert to Persian numbers from English Number
Used for converting English numbers to Persian.

Example:

`persianJs("345").englishNumber(); // returns: ۳۴۵`

5. Convert to English numbers from Arabic and Persian Number
Used for converting Arabic and Persian numbers to English.

Example:

`persianJs("٣٤٥").toEnglishNumber(); // returns: 345`

6. Decode Percent-encoding Characters in URLs
Used to convert unreadable Persian characters in URL to readable characters.

Example:

`persianJs("https://fa.wikipedia.org/wiki/%D8%B5%D9%81%D8%AD%D9%87%D9%94_%D8%A7%D8%B5%D9%84%DB%8C").decodeURL(); //returns https://fa.wikipedia.org/wiki/صفحهٔ_اصلی`

7. Change keyboard layout
Used for converting Persian char to English char.

Example:

`persianJs("لخخلمث").switchKey(); // returns: google`

8. Convert numbers to words
Used for representing numbers as Persian words.

Example:

`persianJs("1372").digitsToWords(); // returns: یک هزار و سیصد و هفتاد و دو`

9) Zero-width non-joiner correction
Example:

`persianJs("آمده ای ولی من رفته ام و می آییم").halfSpace(); // returns: آمده‌ای ولی من رفته‌ام و می‌آییم`

### Chainable using

Example:

`persianJs("علي٤2465").arabicChar().englishNumber().arabicNumber().toString(); // //returns: علی۴۲۴۶۵`